@@ -69,13 +69,13 @@ class CookiePolicy(http_cookiejar.DefaultCookiePolicy):
     Domain=localhost."""
 
     def return_ok_domain(self, cookie, request):
-        if cookie.domain.endswith(request.origin_req_host):
+        if cookie.domain == '.localhost':
             return True
         return http_cookiejar.DefaultCookiePolicy.return_ok_domain(
             self, cookie, request)
 
     def set_ok_domain(self, cookie, request):
-        if cookie.domain.endswith(request.origin_req_host):
+        if cookie.domain == '.localhost':
             return True
         return http_cookiejar.DefaultCookiePolicy.set_ok_domain(
             self, cookie, request)
@@ -184,8 +184,12 @@ class TestApp(object):
         self.JSONEncoder = json_encoder
 
     def get_authorization(self):
-        """Allow to set the HTTP_AUTHORIZATION environ key. Value should looks
-        like ``('Basic', ('user', 'password'))``
+        """Allow to set the HTTP_AUTHORIZATION environ key. Value should look
+        like one of the following:
+
+        * ``('Basic', ('user', 'password'))``
+        * ``('Bearer', 'mytoken')``
+        * ``('JWT', 'myjwt')``
 
         If value is None the the HTTP_AUTHORIZATION is removed
         """
@@ -231,9 +235,10 @@ class TestApp(object):
         Sets a cookie to be passed through with requests.
 
         """
-        cookie_domain = self.extra_environ.get('HTTP_HOST', 'localhost')
+        cookie_domain = self.extra_environ.get('HTTP_HOST', '.localhost')
         cookie_domain = cookie_domain.split(':', 1)[0]
-        cookie_domain = '.' + cookie_domain
+        if '.' not in cookie_domain:
+            cookie_domain = "%s.local" % cookie_domain
         value = escape_cookie_value(value)
         cookie = http_cookiejar.Cookie(
             version=0,
@@ -518,8 +523,15 @@ class TestApp(object):
                         file_info.append(value.content_type)
                 _append_file(file_info)
             else:
-                if isinstance(value, text_type):
+                if isinstance(value, int):
+                    value = str(value).encode('utf8')
+                elif isinstance(value, text_type):
                     value = value.encode('utf8')
+                elif not isinstance(value, (bytes, str)):
+                    raise ValueError((
+                        'Value for field {0} is a {1} ({2}). '
+                        'It must be str, bytes or an int'
+                    ).format(key, type(value), value))
                 lines.extend([
                     b'--' + boundary,
                     b'Content-Disposition: form-data; name="' + key + b'"',
